@@ -142,14 +142,7 @@ def initialize(
     SessionManager.addResource(api, app)
     ApiKeyManager.addResource(api, app)
     SecurityManager.addResource(api, app)
-
     addFlaskApiResources(*[api, app, *[getResourceList(api, resourceType) for resourceType in FlaskManager.KW_RESOURCE_LIST]])
-
-    SessionManager.onShutdown(api, api.app)
-    ApiKeyManager.onShutdown(api, api.app)
-    SecurityManager.onShutdown(api, api.app)
-    SchedulerManager.onShutdown(api, api.app)
-    SqlAlchemyProxy.onShutdown(api, api.app)
     return app
 
 @Function
